Learn R Programming

MiRAnorm (version 1.0.0)

impmat: Imputation function

Description

impmat imputes a dataset entered as rows=Genes, columns=Samples. NA values are imputed by row. Currently, impvalue function imputes these as the max value of the row, the largest observed value for a given Gene across all Samples.

Usage

impmat(data)

Arguments

data
dataset to be imputed. Should contain all numeric values with rows=Genes and columns=Samples.