Usage
miranorm(data = dat, group = dat$Trt, max = 15, min = 3, method = "complex", dis.method = "Euclidean", hclust.method = "single", ct = 25, missing = 0, clustplot = TRUE, selected = 4, ggplot = TRUE, heatmap = TRUE, known.positives = NULL, suggested.list = NULL, exclude = NULL)
Arguments
data
Dataframe containing at a minimum: Sample, Gene, Ct, and Trt
group
Treatment allocation. This should be the same length as the number of rows in data.
max
When method is chosen as "complex", this determines the maximum selected size at which the stability evaluation is done.
min
When method is chosen as "complex", this determines the minimum selected size at which the stability evaluation is done.
method
Choice of "simple" or "complex".
Simple runs a single pass of miranorm for suggested normalizing genes.
Complex runs bootstrap samples across a range of sizes to compute a stability metric.
dis.method
Distance metric used to calculate pairwise distance between individual miRNAs across all samples.
Currently "Euclidean" and "1-Cor" are implemented.
hclust.method
The agglomeration method used to group genes.
Methods are the same as defined in the hclust function in the stats package and include
"single", "average", "complete", and "ward.D2".
"single" is recommended as it is more robust to small perturbations and tends to form the "chaining" phenomenon useful for defining normalizing genes.
ct
Cycle threshold values at or above this level are treated as NA for the purposes of determining normalization genes. Recommend the value be set to 25.
missing
Defines maximum percentage of samples missing for a given gene before that gene is excluded from dataset during normalization.
clustplot
"True" or "False" to output or suppress stability plot. Only applicable if method = "complex".
selected
How many adaptive normalizing genes to search for in panel. Note, actual number of genes found may be larger based on tree cut.
ggplot
"True" or "False" to output general raw data plots.
heatmap
"True or "False" to output or suppress heatmap plot.
known.positives
Names of miRNA that are known positive. These will be added automatically to the heatmap plot.
suggested.list
Names of miRNA that are user suggested normalizing miRNA. These will be added automatically to the heatmap plot.
exclude
List of miRNA to exclude from the selection process for HK genes, eg: known.positives should be included here.