Learn R Programming

MiRAnorm (version 1.0.0)

scr: Replacing values above ct to NA

Description

scr screens the dataset in wide format according to Ct threshold and missing.percent.thresh (for each gene, the percentage of samples is missing). sets all values above Ct threshold to NA and then removes all rows of genes with number of missing above missing.percent.thresh.

Usage

scr(dat, threshold, missing.percent.thresh)

Arguments

dat
the dataset with rows = Genes and columns = Samples.
threshold
Ct value at or above which all values are set to NA.
missing.percent.thresh
a number between 0 to 100 denoting the percentage of allowable missing. If the percentage of missing is greater than this value, the row (gene) is not retained.