scr screens the dataset in wide format according to Ct threshold and missing.percent.thresh (for each gene, the percentage of samples is missing).
sets all values above Ct threshold to NA and then removes all rows of genes with number of missing above missing.percent.thresh.
scr(dat, threshold, missing.percent.thresh)